# Dataset and machine-learning scripts for "Development of highly active catalysts for low-temperature CO2 hydrogenation to methanol using machine learning approach"

## Overview

This project contains Python scripts and Jupyter Notebook files for performing machine learning analysis using the "low-temperature CO2 hydrogenation to methanol in the batch reactor" dataset.
The code uses an Anaconda environment along with several useful libraries.

## Table of Contents

- [Overview](#overview)
- [References](#references)
- [Features](#features)
- [Environment and Dependencies](#environment-and-dependencies)
- [Contributing](#contributing)
- [Usage](#usage)
- [License](#license)
- [Contact](#contact)

## References

Below are the research paper and publications related to this project:
- Title: Development of highly active catalysts for low-temperature CO2 hydrogenation to methanol using machine learning approach
- Authors: `Shirun Zhao`, `Shinya Mine`, `Gang Wang`, `Weiyang Zhang`, `Abdellah Ait El Fakir`, `Bin Yang`, `Zengwei Qin`, `Nazmul Hasan MD Dcostagir`, `Koichi Matsushita`, `Ichigaku Takigawa`, `Ken-ichi Shimizu`, and `Takashi Toyao`
- Published in: [Journal/Conference Name, Year]
- DOI:

## Features

- **Python Scripts:** Perform data processing, analysis, and machine learning tasks.
- **Jupyter Notebooks:** Provide interactive examples and visualizations.

## Environment and Dependencies

This project is set up to run in an **Anaconda** environment. Below are the main libraries used:

### Standard Libraries
- `sys`, `os`, `glob`, `subprocess`, `warnings`, `argparse`, `random`, `collections`, `itertools`, `Counter`, `math`

### Data Processing and Computation
- `numpy`
- `pandas`

### Visualization
- `matplotlib` (including `matplotlib.pyplot`)
- `seaborn`
- `adjustText`

### Statistical Analysis
- `scipy`

### System Monitoring
- `psutil`

### Machine Learning
- **scikit-learn:**  >= version 1.3.0
  Includes modules such as `ExtraTreesRegressor`, `RandomForestRegressor`, `Lasso`, `Ridge`, `SVR`, `ShuffleSplit`, `KFold`, `GridSearchCV`, `train_test_split`, `LeaveOneOut`, `mean_squared_error`, `mean_absolute_error`, `r2_score`, `StandardScaler`, and Gaussian process tools.


### Model Explainability
- `shap`== version 0.42.1

For exact package versions, please refer to the `mine.yml` file.

## Usage
All the directories are downloaded in compressed ZIP file format, so please unzip them before executing the code (.piynb).

## Licence
This project is licensed under the `CC BY 4.0` license.

## Contact
If you have any questions or suggestions, feel free to reach out:
- Email: `s.mine@aist.go.jp`