#!/usr/bin/env python
import sys
sys.dont_write_bytecode = True

def calc_condition() -> dict:
    condition = {}

    ### Basic calculation conditions ###
    date = 20250604
    computer = 'B'  # Select 'A' or 'B' or 'I' (default: B)
    core = 112  # default: A==68, B==36, I==36
    hyper_threading = False  # default: False
    Reaction = 'CH3OH_Batch'
    test_cal = False # default: False
    data_sheet_name = 'test_data'
    train_data_sheet_name = 'other_data'
    ML_model = 'ETR'  # or 'RFR'
    desc_std = False  # default: False (Standardization)
    n_est = 100
    skip_rows = 0

    ### Define ML model
    # 0: Direct input representation,
    # 1: Exploitative elemental descriptor representation
    # 2: Explorative elemental descriptor representation
    pgm_model = 0
    add_model = 1
    supp_model = 1
    Search_method = 'grid'  # or 'local'

    ### Input catalyst shapes (Check your dataset.xlsx files) ###
    pgm_num = 3  # default: 3
    add_num = 4  # default: 4
    supp_num = 1  # default: 1

    ### Output conditions ###
    cut_size = int(5E5)
    save_depth = 100  # if save_depth == -1: full depth
    catal_number = 100
    K_cluster = 100
    extractions = []  # Option of extractions

    ### Define the input catalytic compositions ###
    # 1. PGMs
    cand_pgm_num = 3
    pgm_wt = [0, 0.3, 0.5, 1, 4, 4.5]
    fix_pgm_num = 0                     # # 0, 1, 2, ..., max_pgm_num-1
    max_pgm_wt = 5
    essential_pgms = ['Pt']                # if fix_pgm_num == 0: this list has no meaning.
    essential_pgm_wt = [0, 0.3, 0.5, 1, 4, 4.5, 4.7, 5]        # 'CH3OH_Batch':'Pt' is 'essential_pgm'       
    drop_pgms = []
    specific_pgms = []
    specific_pgm_wt = []

    # 2. Additives
    cand_add_num = 4
    add_wt = [0, 1, 2.5, 6, 9, 12]
    fix_add_num = 3                     # 0, 1, 2, ..., max_add_num-1
    max_add_wt = None
    essential_adds = ['Mo', 'W', 'Re', 'Yb', 'Ti', 'Zr', 'P']               # if fix_add_num == 0: this list has no meaning.
    essential_add_wt = add_wt
    drop_adds = []
    specific_adds = []
    specific_add_wt = []

    # 3. Supports
    cand_supp_num = 1
    essential_supp = []                 # if fix_supp_num == 0: this list has no meaning.(ex. 'Al2O3_gamma', ...)
    fix_supp_num = len(essential_supp)
    drop_supp_list = []

    # 4. Reaction conditions
    CalT_num = 1                         # 0(False) or 1(True)
    CalT_list = [400, 500, 600]                    # if CalT_num == 0: this list has no meaning.


    ### Define target name ###
    if Reaction == 'CH3OH_Batch':
        target_name = 'CH3OH rate (mmol g-1 h-1)'
        #target_name = 'CH3OH rate x selec'
        target_temp = -1
    else:
        target_name = 'target'
        target_temp = -1


    ### Local search ###
    perturb_num_list = [30, 30, 30]  # [All, elems, supp_&_exp]
    sigma_pgm = 0.05
    sigma_add = 0.05
    sigma_CalT = 0.05

    ################ Do NOT edit !!! #################
    if test_cal == True:
        save_depth = -1
        pgm_wt = [0.1]
        essential_pgm_wt = [0.1]
        specific_pgm_wt = [0.1]
        add_wt = [10]
        essential_add_wt = [10]
        specific_add_wt = [10]

        CalT_num = 1
        CalT_list = [500]
    ################ Do NOT edit !!! #################

    ### Final condition dictionary ###
    condition = {
        'date': date, 'computer': computer, 'core': core, 'Reaction': Reaction,
        'hyper_threading': hyper_threading, 'test_cal': test_cal,
        'data_sheet_name': data_sheet_name, 'train_data_sheet_name': train_data_sheet_name,
        'cut_size': cut_size, 'n_est': n_est, 'ML_model': ML_model, 'desc_std': desc_std,
        'pgm_model': pgm_model, 'add_model': add_model, 'supp_model': supp_model,
        'Search_method': Search_method,
        'cand_pgm_num': cand_pgm_num, 'cand_add_num': cand_add_num, 'cand_supp_num': cand_supp_num,
        'fix_pgm_num': fix_pgm_num, 'pgm_num': pgm_num, 'add_num': add_num, 'supp_num': supp_num,
        'max_pgm_wt': max_pgm_wt, 'max_add_wt': max_add_wt,
        'essential_pgms': essential_pgms, 'essential_pgm_wt': essential_pgm_wt, 'pgm_wt': pgm_wt,
        'add_wt': add_wt, 'fix_add_num': fix_add_num,
        'essential_adds': essential_adds, 'essential_add_wt': essential_add_wt,
        'specific_pgms': specific_pgms, 'specific_pgm_wt': specific_pgm_wt,
        'specific_adds': specific_adds, 'specific_add_wt': specific_add_wt,
        'drop_pgms': drop_pgms, 'drop_adds': drop_adds,
        'fix_supp_num': fix_supp_num, 'essential_supp': essential_supp, 'drop_supp_list': drop_supp_list,
        'CalT_num': CalT_num, 'CalT_list': CalT_list,
        'save_depth': save_depth, 'catal_number': catal_number, 'K_cluster': K_cluster, 'extractions': extractions,
        'target_name': target_name, 'target_temp': target_temp, 'skip_rows': skip_rows,
        'perturb_num_list': perturb_num_list, 'sigma_pgm': sigma_pgm, 'sigma_add': sigma_add, 'sigma_CalT': sigma_CalT, 
    }

    return condition



def desc_select(Reaction:str) -> dict:
    selec_desc = {}
    elem_all_desc = [
        'AN', 'Group', 'Period', 'AW', 'Atom rad', 'Atom rad emp',
        'Ion rad', 'Coval rad', 'Coval rad 3', 'vdW rad', 'Crys rad',
        'Metal bond rad', 'EN_Allred', 'EN_Pauling', 'EN_Mulliken', 'EN_Allen',
        'EN_M&B', 'EN_T&O', 'm.p.', 'b.p.', 'd_fus_H', 'Density',
        'Thermal expansion', 'Heat capacity', 'Thermal conductivity',
        'Ionization energy', 'Electron affinity', 'Valence electron',
        'Valence electron VASP', 'E_surf', 'd_desoc_H_homo', 'd_desoc_H_hetero', 'FMM Metal',
        'E_form Metal', 'BG Metal', 'Work function', 'Eads_CO2', 'OCO_angle',
        'Eads_H', 'Eads_H2', 'Eads_C', 'Eads_N', 'Eads_N2', 'Eads_O', 'Eads_O2',
        'MW_Oxide', 'Stable oxidation number', 'FMM Oxide',
        'E_form Oxide', 'Density Oxide', 'BG Oxide',
        'Precursor oxidation number', 'MW_Precursor', 'Solubility',
        ]
    
    supp_all_desc = [
        'MW', 'EN_bulk', 'E_form',
        'BG_PBEsol', 'E_surf', 'Ionization potential', 'Electron affinity',
        'Work function', 'Evac', 'BG MP', 'E_form MP',
        'Magnetization', 'Density', 'Poisson Ratio', 'Elastic_Prop_Bulk_Voigt',
        'm.p.', 'b.p.', 'd_form_H_298K', 'std_mol_S', 'std_mol_Cp', 'Eads_H2',
        'Eads_CO2', 'Eads_CO', 'Eads_NO', 'Eads_N2O', 'Eads_CH4', 'Eads_CH3OH',
        'Eads_C2H5OH', 'Edisads_HCOOH', 'Edisads_CH3COOH', 'SSA specification',
        'SSA w/o cal', 'SSA cal at 700℃', 'N2 uptake at P/P0=0.015',
        'N2 uptake at P/P0=0.015 at 700℃', 'IR L acid intensity',
        'IR L acid cm-1', 'IR B acid intensity', 'IR B acid cm-1',
        'IR L acid intensity cal at 700℃', 'IR L acid cm-1 cal at 700℃',
        'IR B acid intensity cal at 700℃', 'IR B acid cm-1 cal at 700℃',
        'Si/Al ratio', 'Pore size'
       ]
    
    
    if Reaction == 'CH3OH_Batch':

        pgm_use_desc = [
            'Atom rad', 'E_surf', 'Eads_CO2',
            ]
        pgm_drop_desc = [
            'Eads_N', 'Eads_N2',
            'MW_Oxide', 'Stable oxidation number','FMM Oxide', 'E_form Oxide',
            'Density Oxide', 'BG Oxide',
            ]

        add_use_desc = [
            'E_form Metal',
            'Thermal expansion', 'E_surf',
            'Solubility', 'Eads_CO2',
            ]
        add_drop_desc = [
            'Eads_N', 'Eads_N2',
            'FMM Metal', 'E_form Metal',
            ]
        
        supp_use_desc = [
            'EN_bulk', 'Ionization potential', 'Density', 'BG_PBEsol',
            ]
        supp_drop_desc = [
            'Eads_NO', 'Eads_N2O', 'Eads_C2H5OH',
            ]

    selec_desc = {
        'all_elem': elem_all_desc, 'all_supp': supp_all_desc,
        'use_pgm': pgm_use_desc, 'use_add': add_use_desc, 'use_supp': supp_use_desc,
        'drop_pgm': pgm_drop_desc, 'drop_add': add_drop_desc,'drop_supp': supp_drop_desc,
        }
    
    return selec_desc